@@ -115,6 +115,11 @@ def ApplyExtinctionrules(HKL, Extinc, verbose=0):
         cond = cond1 * cond2
         array_hkl = np.take(HKL, np.where(cond == True)[0], axis=0)
 
+    elif Extinc == "SG166":
+        cond = (-H + K + L) % 3 == 0
+        array_hkl = np.take(HKL, np.where(cond == True)[0], axis=0)
+        
+
     elif Extinc == "Ti2AlN":
         # wurtzite condition
         condfirst = (H == K) * ((L % 2) != 0)
@@ -149,26 +154,42 @@ def ApplyExtinctionrules(HKL, Extinc, verbose=0):
     #
     #         array_hkl = np.take(array_hkl_1, np.where(cond6 == True)[0], axis=0)
 
-    elif Extinc == "magnetite":  # GS 227
-        # TODO not working ...
+    elif Extinc == "SG141":  # SG 141 ( Sn beta)
+        # general existence conditions for any h k l (take!)
+        cond1 = (H + K + L) % 2 == 0
+        array_hkl_1 = np.take(HKL, np.where(cond1 == True)[0], axis=0)
+        
+        H, K, L = array_hkl_1.T
+
+        # general existence conditions for specific cases h k l (delete!)
+
+        chk0 = (L == 0) * ((H) % 2 != 0)*((K) % 2 != 0)
+        c0kl = (H == 0) * ((K + L) % 2 != 0)
+        chhl = (H == K) * ((2* H + L) % 4 != 0)
+        c00l = (H == 0) * (K == 0) * ((L) % 4 != 0)
+        ch00 = (K == 0) * (L == 0) * ((H) % 2 != 0)
+        chhb0 =  (K == -H) * (L == 0) * ((H) % 2 != 0)
+
+        cond = chk0+ c0kl + chhl + c00l + ch00 + chhb0
+
+        array_hkl = np.delete(array_hkl_1, np.where(cond == True)[0], axis=0)
+        
+    elif Extinc == "SG227":  # SG 227 ( Sn alpha, magnetite)
+        #print("len start", len(H))
         cond = ((H + K) % 2 == 0) * ((H + L) % 2 == 0) * ((K + L) % 2 == 0)
 
         array_hkl_1 = np.take(HKL, np.where(cond == True)[0], axis=0)
 
-        print("len", len(array_hkl_1))
-
         H, K, L = array_hkl_1.T
 
-        cond0kl_1 = ((K) % 2 == 0) * ((L) % 2 == 0) * ((K + L) % 4 != 0)
-        cond0kl_2 = ((H) % 2 == 0) * ((L) % 2 == 0) * ((H + L) % 4 != 0)
-        cond0kl_3 = ((H) % 2 == 0) * ((K) % 2 == 0) * ((H + K) % 4 != 0)
+        cond0kl_1 = (H==0) * ((K) % 2 != 0) * ((L) % 2 != 0) * ((K + L) % 4 != 0)
+        cond0kl_2 = (K==0)  * ((H) % 2 != 0) * ((L) % 2 != 0) * ((H + L) % 4 != 0)
+        cond0kl_3 = (L==0)  * ((H) % 2 != 0) * ((K) % 2 != 0) * ((H + K) % 4 != 0)
 
-        cond0kl = (H == 0) * cond0kl_1 + (K == 0) * cond0kl_2 + (L == 0) * cond0kl_3
+        cond0kl = cond0kl_1 + cond0kl_2 + cond0kl_3
 
         array_hkl_2 = np.delete(array_hkl_1, np.where(cond0kl == True)[0], axis=0)
 
-        print("len", len(array_hkl_2))
-
         H, K, L = array_hkl_2.T
 
         condhhl_1 = (H == K) * ((H + L) % 2 != 0)
@@ -179,8 +200,6 @@ def ApplyExtinctionrules(HKL, Extinc, verbose=0):
 
         array_hkl_3 = np.delete(array_hkl_2, np.where(condhhl == True)[0], axis=0)
 
-        print("len 3", len(array_hkl_3))
-
         H, K, L = array_hkl_3.T
 
         condh00_1 = (K == 0) * (L == 0) * (H % 4 != 0)
@@ -189,27 +208,26 @@ def ApplyExtinctionrules(HKL, Extinc, verbose=0):
 
         condh00 = condh00_1 + condh00_2 + condh00_3
 
-        array_hkl_0 = np.delete(array_hkl_3, np.where(condh00 == True)[0], axis=0)
+        array_hkl = np.delete(array_hkl_3, np.where(condh00 == True)[0], axis=0)
 
-        print("len f", len(array_hkl_0))
+        # magnetite --------------
+        # H, K, L = array_hkl_0.T
+        
+        # cond8a = ((H % 2 == 1) + (K % 2 == 1) + (L % 2 == 1)) + ((H + K + L) % 4 == 0)
 
-        H, K, L = array_hkl_0.T
+        # array_hkl_00 = np.take(array_hkl_0, np.where(cond8a == True)[0], axis=0)
 
-        cond8a = ((H % 2 == 1) + (K % 2 == 1) + (L % 2 == 1)) + ((H + K + L) % 4 == 0)
+        # print("len", len(array_hkl_00))
 
-        array_hkl_00 = np.take(array_hkl_0, np.where(cond8a == True)[0], axis=0)
+        # H, K, L = array_hkl_00.T
 
-        print("len", len(array_hkl_00))
+        # cond16d = (((H % 2 == 1) + (K % 2 == 1) + (L % 2 == 1))
+        #     + ((H % 4 == 2) * (K % 4 == 2) * (L % 4 == 2))
+        #     + ((H % 4 == 0) * (K % 4 == 0) * (L % 4 == 0)))
 
-        H, K, L = array_hkl_00.T
+        # array_hkl = np.take(HKL, np.where(cond16d == True)[0], axis=0)
 
-        cond16d = (((H % 2 == 1) + (K % 2 == 1) + (L % 2 == 1))
-            + ((H % 4 == 2) * (K % 4 == 2) * (L % 4 == 2))
-            + ((H % 4 == 0) * (K % 4 == 0) * (L % 4 == 0)))
-
-        array_hkl = np.take(HKL, np.where(cond16d == True)[0], axis=0)
-
-        print("len", len(array_hkl))
+        # print("len", len(array_hkl))
 
     elif Extinc == "Al2O3_rhombo":
         cond1 = (H - K) == 0
