@@ -24,12 +24,12 @@ try:
     else:
         import gaussian2D
 
+
     USE_CYTHON = True
 except ImportError:
-    print("Cython compiled module 'gaussian2D' for fast computation is not installed!")
+    #print("warning. Cython compiled module 'gaussian2D' for fast computation is not installed!")
     USE_CYTHON = False
 
-
 def gaussian(height, center_x, center_y, width_x, width_y):
     """Returns a gaussian function with the given parameters"""
     width_x = float(width_x)
@@ -59,7 +59,7 @@ def fitgaussian(data):
     the gaussian parameters of a 2D distribution found by a fit"""
     params = moments(data)
     errorfunction = lambda p: np.ravel(gaussian(*p)(*np.indices(data.shape)) - data)
-    p, success = optimize.leastsq(errorfunction, params)
+    p, _ = optimize.leastsq(errorfunction, params)
     return p
 
 
@@ -161,7 +161,6 @@ def twodgaussian(inpars, circle, rotate, vheight):
 
     return rotgauss
 
-
 def twodgaussian_2peaks(inpars, circle, rotate, vheight):
     """Returns a 2d gaussian function of the form:
     x' = cos(rota) * x - sin(rota) * y
