@@ -37,6 +37,7 @@ else:
     import generaltools as GT
     import dict_LaueTools as DictLT
 
+
 listfile = os.listdir(os.curdir)
 
 def getindices2cropArray(center, halfboxsizeROI, arrayshape, flipxycenter=False):
@@ -69,10 +70,12 @@ def getindices2cropArray(center, halfboxsizeROI, arrayshape, flipxycenter=False)
     else:
         boxsizex, boxsizey = halfboxsizeROI
 
-    x1 = np.maximum(0, xpic - boxsizex)
-    x2 = np.minimum(arrayshape[0], xpic + boxsizex)
-    y1 = np.maximum(0, ypic - boxsizey)
-    y2 = np.minimum(arrayshape[1], ypic + boxsizey)
+    # TODO check also  if xpic and ypic is within framedim
+
+    x1 = max(0, xpic - boxsizex)
+    x2 = min(arrayshape[0], xpic + boxsizex)
+    y1 = max(0, ypic - boxsizey)
+    y2 = min(arrayshape[1], ypic + boxsizey)
 
     imin, imax, jmin, jmax = int(y1), int(y2), int(x1), int(x2)
 
@@ -642,7 +645,7 @@ def LocalMaxima_KernelConvolution(Data, framedim=(2048, 2048),
                                 connectivity=connectivity,
                                 returnfloatmeanpos=0)
 
-    if not peak:
+    if len(peak) == 0:
         return None
 
     peak = (peak[:, 0], peak[:, 1])
@@ -957,7 +960,7 @@ def LocalMaxima_ShiftArrays(Data, framedim=(2048, 2048), IntensityThreshold=500,
 
     purged_pklist, index_todelete = GT.purgeClosePoints2(th_peaklist, pixeldistance)
 
-    purged_amp = np.delete(th_ar_amp, index_todelete)
+    purged_amp = np.delete(th_ar_amp, tuple(index_todelete))
     print(
         "{} local maxima found after removing duplicates (minimum intermaxima distance = {})".format(
             len(purged_amp), pixeldistance))
@@ -1295,7 +1298,7 @@ def compute_autobackground_image(dataimage, boxsizefilter=10):
 
 
 def computefilteredimage(dataimage, bkg_image, CCDlabel, kernelsize=5, formulaexpression="A-B",
-                                                        usemask=True):
+                                                        usemask=True, verbose=0):
     r"""
     return 2D array of initial image data without background given by bkg_image data
 
@@ -1314,8 +1317,9 @@ def computefilteredimage(dataimage, bkg_image, CCDlabel, kernelsize=5, formulaex
     SaturationLevel = DictLT.dict_CCD[CCDlabel][2]
     dataformat = DictLT.dict_CCD[CCDlabel][5]
 
-    print("framedim in computefilteredimage ", framedim)
-    print("CCDlabel in computefilteredimage ", CCDlabel)
+    if verbose:
+        print("framedim in computefilteredimage ", framedim)
+        print("CCDlabel in computefilteredimage ", CCDlabel)
     #
     #     if CCDlabel in ('EDF',):
     #         return dataimage
@@ -1336,8 +1340,8 @@ def computefilteredimage(dataimage, bkg_image, CCDlabel, kernelsize=5, formulaex
         mask_radius = min(framedim[0] // 2, framedim[1] // 2) - 15
         center, minvalue = (framedim[0] // 2, framedim[1] // 2), 0
 
-        print("mask_radius", mask_radius)
-        print("center", center)
+        # print("mask_radius", mask_radius)
+        # print("center", center)
 
         dataarray2D_without_background = filterimage(dataimage, framedim,
                                                     blurredimage=bkg_image,
