@@ -15,14 +15,11 @@ import sys
 import os
 import copy
 import time as ttt
-
-import configparser as CONF
-
 import numpy as np
 
-
 # lauetools modules
 if sys.version_info.major == 3:
+    import configparser as CONF
     from . import fit2Dintensity as fit2d
     from . import fit2Dintensity_Lorentz as fit2d_l
     from . import generaltools as GT
@@ -30,7 +27,9 @@ if sys.version_info.major == 3:
     from . import IOimagefile as IOimage
     from . import dict_LaueTools as DictLT
     from . import imageprocessing as ImProc
+
 else:
+    import ConfigParser as CONF
     import fit2Dintensity as fit2d
     import fit2Dintensity_Lorentz as fit2d_l
     import generaltools as GT
@@ -122,30 +121,14 @@ def readoneimage_multiROIfit(filename, centers, boxsize, stackimageindex=-1, CCD
     :param offsetposition: integer, 0 for no offset, 1  XMAS compatible, since XMAS consider first pixel as index 1 (in array, index starts with 0), 2  fit2d, since fit2d for peaksearch put pixel labelled n at the position n+0.5 (between n and n+1)
     :param use_data_corrected: tuple of 3 elements, Enter data instead of reading data from file:
                          fulldata, framedim, fliprot
-                         where fulldata is a ndarray
+                         where fulldata is a 2D ndarray
     :return: list of results:   bkg,  amp  (gaussian height-bkg), X , Y, major axis standard deviation, minor axis standard deviation,
                                 major axis tilt angle / Ox
     .. todo:: setting list of initial guesses can be improve with
         scipy.ndimages of a concatenate array of multiple slices?
     """
     if verbose > 0: print("addImax", addImax)
-    #     print "entrance of readoneimage_multiROIfit", (filename,
-    #                              centers,
-    #                              boxsize,
-    #                              CCDLabel,
-    #                              baseline,
-    #                              startangles,
-    #                              start_sigma1,
-    #                              start_sigma2,
-    #                              position_start,
-    #                              fitfunc,
-    #                              showfitresults,
-    #                              offsetposition,
-    #                              verbose,
-    #                              xtol,
-    #                              addImax,
-    #                              use_data_corrected)
-
+    
     # read data (several arrays)
     ResData = IOimage.readoneimage_manycrops(filename,
                                     centers,
@@ -892,13 +875,17 @@ def PeakSearch(filename, stackimageindex=-1, CCDLabel="PRINCETON", center=None,
                 - estimating the background around a peak
                 - shifting array in second method of local maxima search (shifted arrays)
 
-    :param IntensityThreshold: integer, pixel intensity level above which potential peaks are kept for fitting position procedure. For local maxima method 0 and 1, this level is relative to zero intensity. For local maxima method 2, this level is relative to lowest intensity in the ROI (local background). Advice: start with high value, because if too high, few peaks are found (only the most important), and if too low, too many local maxima are found leading to time consuming fitting procedure.
+    :param IntensityThreshold: integer, pixel intensity level above which potential peaks are kept for fitting position procedure. For local maxima method 0 and 1, this level is relative to zero intensity. For local maxima method 2, this level is relative to lowest intensity in the ROI (local background).
+    
+    .. note:: Start with high value, because if too high, few peaks are found (only the most important), and if too low, too many local maxima are found leading to time consuming fitting procedure.
 
     :param thresholdConvolve: integer, pixel intensity level in convolved image above which potential peaks are kept for fitting position procedure. This threshold step on convolved image is applied prior to the local threshold step with IntensityThreshold on initial image (with respect to the local background)
 
     :param paramsHat: mexican hat kernel parameters (see :func:`LocalMaxima_ndimage`)
 
-    :param PixelNearRadius: integer, pixel distance between two regions considered as peaks. Advice: start rather with a large value. If too low, there are very much peaks duplicates and this is very time consuming.
+    :param PixelNearRadius: integer, pixel distance between two regions considered as peaks.
+    
+    .. note:: Start rather with a large value. If too low, there are very much peaks duplicates and this is very time consuming.
 
     :param local_maxima_search_method: integer, Select method for find the local maxima, each of them will fitted
                             - 0   extract all pixel above intensity threshold
@@ -909,9 +896,11 @@ def PeakSearch(filename, stackimageindex=-1, CCDLabel="PRINCETON", center=None,
 
     :param Saturation_value_flatpeak: saturation value of detector for local maxima search method 1
 
-    :param Remove_BlackListedPeaks_fromfile: None or full file path to a peaklist file containing peaks
-                                            that will be deleted in peak list resulting from
-                                            the local maxima search procedure (prior to peak refinement)
+    :param Remove_BlackListedPeaks_fromfile:
+        - None
+        - file fullpath, str,  to a peaklist file containing peaks that will be deleted in peak list resulting from
+        the local maxima search procedure (prior to peak refinement)
+        - ndarray of nx2 X Y pixels cooordinates (avoid reading file in peaksearch series)
 
     :param maxPixelDistanceRejection: maximum distance between black listed peaks and current peaks
                                     (found by peak search) to be rejected
@@ -928,13 +917,13 @@ def PeakSearch(filename, stackimageindex=-1, CCDLabel="PRINCETON", center=None,
                             and refined peak position
 
     :param position_definition: due to various conventional habits when reading array, add some offset to fitdata XMAS or fit2d peak search values:
-        - 0    no offset (python numpy convention)
-        - 1   XMAS offset
-        - 2   fit2d offset
+        - 0   no offset (python numpy convention)
+        - 1   XMAS offset (first pixel is counted as located at 1 instead of 0)
+        - 2   fit2d offset (obsolete)
 
-    :param return_histo: 0   3 output elements
-                        : 1   4 elemts, last one is histogram of data
-                        : 2   4 elemts, last one is the nb of raw blob found after convolution and threshold
+    :param return_histo: - 0   3 output elements
+                         - 1   4 elemts, last one is histogram of data
+                         - 2   4 elemts, last one is the nb of raw blob found after convolution and threshold
 
     :param Data_for_localMaxima:  object to be used only for initial step of finding local maxima (blobs) search
                                 (and not necessarly for peaks fitting procedure):
@@ -989,7 +978,7 @@ def PeakSearch(filename, stackimageindex=-1, CCDLabel="PRINCETON", center=None,
                                                 stackimageindex=stackimageindex,
                                                 CCDLabel=CCDLabel,
                                                 dirname=None,
-                                                verbose=1)
+                                                verbose=verbose)
         
         if verbose: print("image from filename {} read!".format(filename))
 
@@ -1019,7 +1008,8 @@ def PeakSearch(filename, stackimageindex=-1, CCDLabel="PRINCETON", center=None,
         if verbose: print("Using Data_for_localMaxima for local maxima search: --->", Data_for_localMaxima)
         # compute and remove background from this image
         if Data_for_localMaxima == "auto_background":
-            print("computing background from current image ", filename)
+            if verbose:
+                print("computing background from current image ", filename)
             backgroundimage = ImProc.compute_autobackground_image(Data, boxsizefilter=10)
             # basic substraction
             usemask = True
@@ -1148,19 +1138,20 @@ def PeakSearch(filename, stackimageindex=-1, CCDLabel="PRINCETON", center=None,
                 len(peaklist), nb_peaks_before))
     # -----------------------------------------------
 
+    #-------------------------------------------------
     # remove black listed peaks option
-    if Remove_BlackListedPeaks_fromfile is not None:
-
-        data_peak_blacklisted = IOLT.read_Peaklist(Remove_BlackListedPeaks_fromfile, dirname=None)
-
-        #         print "data_peak_blacklisted", data_peak_blacklisted
-
-        if len(peaklist) > 1 and len(data_peak_blacklisted) > 1:
-
-            XY_blacklisted = data_peak_blacklisted[:, :2].T
+    # and update peaklist
+    if Remove_BlackListedPeaks_fromfile is not None and len(peaklist)>1:
+        if not isinstance(Remove_BlackListedPeaks_fromfile, str):
+            # array of XY  shape = (n,2)
+            XY_blacklisted = Remove_BlackListedPeaks_fromfile
 
+        elif Remove_BlackListedPeaks_fromfile.endswith(('.dat', '.fit')):
+            XY_blacklisted = Get_blacklisted_spots(Remove_BlackListedPeaks_fromfile)
+        
+        if XY_blacklisted is None: print('No or only 1 Blacklisted spots found...')
+        else:  #
             X, Y = peaklist[:, :2].T
-
             (peakX, _, tokeep) = GT.removeClosePoints_two_sets([X, Y], XY_blacklisted,
                                                         dist_tolerance=maxPixelDistanceRejection,
                                                         verbose=0)
@@ -1173,16 +1164,11 @@ def PeakSearch(filename, stackimageindex=-1, CCDLabel="PRINCETON", center=None,
                     npeak_before,
                     Remove_BlackListedPeaks_fromfile))
 
-            #             print "peaklist before", peaklist
-            #             print "peakX, peakY blacklisted", XY_blacklisted
-
             peaklist = np.take(peaklist, tokeep, axis=0)
             Ipixmax = Ipixmax[tokeep]
-
-    #             print "peaklist after blacklist removal", peaklist
+    #-------------------------------------------------
 
     # ---- ----------- no FITTING ----------------------------
-
     # NO FIT  and return raw list of local maxima
     if fit_peaks_gaussian == 0:
 
@@ -1233,11 +1219,6 @@ def PeakSearch(filename, stackimageindex=-1, CCDLabel="PRINCETON", center=None,
         print("{} local maxima found".format(len(peaklist)))
         print("\n Fitting of each local maxima\n")
 
-    #    print "framedim", framedim
-    #    print "offset", offset
-    #    print "formatdata", formatdata
-    #    print "fliprot", fliprot
-
     if center is not None:
         position_start = "centers"
     else:
@@ -1270,6 +1251,28 @@ def PeakSearch(filename, stackimageindex=-1, CCDLabel="PRINCETON", center=None,
                                 use_data_corrected=Data_to_Fit,
                                 reject_negative_baseline=reject_negative_baseline)
 
+def Get_blacklisted_spots(filename):
+    XY_blacklisted = None
+    if filename.endswith('.dat'):
+
+        data_peak_blacklisted = IOLT.read_Peaklist(filename, dirname=None)
+        if len(data_peak_blacklisted) > 1:
+
+            XY_blacklisted = data_peak_blacklisted[:, :2].T
+
+    elif filename.endswith('.fit'):
+        resdata = IOLT.readfile_fit(filename)
+        if resdata is not None:
+            allgrainsspotsdata = resdata[4]
+            nspots = len(allgrainsspotsdata)
+        else:
+            nspots = 0
+
+        if nspots > 1:
+
+            XY_blacklisted = allgrainsspotsdata[:, 7:9].T
+            
+    return XY_blacklisted
 
 def peaksearch_on_Image(filename_in, pspfile, background_flag="no", blacklistpeaklist=None,
                                                         dictPeakSearch={},
@@ -1567,7 +1570,7 @@ def set_rois_file(filepathstr):
 
 # --- -------------- multiple file peak search
 def peaksearch_fileseries(fileindexrange,
-                            filenameprefix,
+                            filenameprefix="",
                             suffix="",
                             nbdigits=4,
                             dirname_in="/home/micha/LaueProjects/AxelUO2",
@@ -1576,10 +1579,14 @@ def peaksearch_fileseries(fileindexrange,
                             CCDLABEL="MARCCD165",
                             KF_DIRECTION="Z>0",  # not used yet
                             dictPeakSearch=None,
-                            verbose=0):
+                            verbose=0,
+                            writeResultDicts=0,
+                            computetime=0):
     r"""
     peaksearch function to be called for multi or single processing
     """
+    if computetime:
+        t0 = ttt.time()
     print('\n\n ***** Starting peaksearch_fileseries()  *****\n\n')
     # peak search Parameters update from .psp file
     if isinstance(dictPeakSearch, dict):
@@ -1589,7 +1596,7 @@ def peaksearch_fileseries(fileindexrange,
     if "MinPeakSize" not in PEAKSEARCHDICT_Convolve:
         PEAKSEARCHDICT_Convolve["MinPeakSize"] = 0.65
         PEAKSEARCHDICT_Convolve["MaxPeakSize"] = 3.
-        print("Default values for minimal and maximal peaksize are used!. Resp. 0.65 and 3 pixels.")
+        if verbose: print("Default values for minimal and maximal peaksize are used!. Resp. 0.65 and 3 pixels.")
 
     PEAKSEARCHDICT_Convolve["PeakSizeRange"] = (copy.copy(PEAKSEARCHDICT_Convolve["MinPeakSize"]),
                                                 copy.copy(PEAKSEARCHDICT_Convolve["MaxPeakSize"]))
@@ -1599,12 +1606,9 @@ def peaksearch_fileseries(fileindexrange,
     # ----handle reading of filename
     # special case for _mar.tif files...
     if nbdigits in ("varying",):
-        # DEFAULT_DIGITSENCODING = 4
-        # encodingdigits = "{" + ":0{}".format(DEFAULT_DIGITSENCODING) + "}"
         pass
     # normal case
     else:
-        # encodingdigits = "{" + ":0{}".format(int(nbdigits)) + "}"
         nbdigits = int(nbdigits)
 
     if suffix == "":
@@ -1615,8 +1619,6 @@ def peaksearch_fileseries(fileindexrange,
     else:
         filenameprefix_in = filenameprefix
 
-    # filename_wo_path = filenameprefix_in.split("/")[-1]
-
     if outputname != None:
         prefix_outputname = outputname
     else:
@@ -1639,20 +1641,24 @@ def peaksearch_fileseries(fileindexrange,
 
         fullpath_backgroundimage = PEAKSEARCHDICT_Convolve["Data_for_localMaxima"]
 
-
-        # dirname_bkg, imagefilename_bkg = os.path.split(fullpath_backgroundimage)
-
-        # CCDlabel_bkg = CCDLABEL
-
-        # (dataimage_bkg, _, _) = IOimage.readCCDimage(imagefilename_bkg,
-        #                                                             CCDLabel=CCDlabel_bkg,
-        #                                                             dirname=dirname_bkg)
-
         BackgroundImageCreated = True
 
-    for fileindex in list(range(fileindexrange[0],
+    # create
+    blspots = PEAKSEARCHDICT_Convolve["Remove_BlackListedPeaks_fromfile"]
+    if blspots is not None:
+        PEAKSEARCHDICT_Convolve["Remove_BlackListedPeaks_fromfile"] = Get_blacklisted_spots(blspots)
+        if PEAKSEARCHDICT_Convolve["Remove_BlackListedPeaks_fromfile"] is None:
+            print('Warning!! blacklisted spots file may not be well read! blacked spots list is empty', PEAKSEARCHDICT_Convolve["Remove_BlackListedPeaks_fromfile"])
+
+    DictPeaksList = {}
+    file_ix, nb_empty_files = 0, 0  # nb of probed file, nb of zero peaks file
+    listimageindices = list(range(fileindexrange[0],
                         fileindexrange[1] + 1,
-                        fileindexrange[2])):
+                        fileindexrange[2]))
+    nbimages = len(listimageindices)
+    nbstepsprogress = 5
+    progressstep = 0
+    for fileindex in listimageindices:
         # TODO to move this branching elsewhere (readmccd)
         if suffix.endswith("_mar.tif"):
             filename_in = IOimage.setfilename(filenameprefix_in + "{}".format(fileindex) + suffix,
@@ -1682,19 +1688,8 @@ def peaksearch_fileseries(fileindexrange,
                 raise ValueError('Missing "formulaexpression" to operate on images before '
                                 'peaksearch in peaksearch_fileseries()')
 
-            # saturationlevel = DictLT.dict_CCD[CCDLABEL][2]
-
-            # dataimage_corrected = applyformula_on_images(dataimage_raw,
-            #                                             dataimage_bkg,
-            #                                             formulaexpression=formulaexpression,
-            #                                             SaturationLevel=saturationlevel,
-            #                                             clipintensities=True)
-
             if verbose: print("using {} in peaksearch_fileseries".format(formulaexpression))
 
-            #             print 'Imin Imax dataimage_raw', np.amin(A), np.amax(A)
-            #             print 'Imin Imax dataimage_bkg', np.amin(B), np.amax(B)
-
             # for finding local maxima in image from formula
             PEAKSEARCHDICT_Convolve["Data_for_localMaxima"] = fullpath_backgroundimage
 
@@ -1703,8 +1698,6 @@ def peaksearch_fileseries(fileindexrange,
             PEAKSEARCHDICT_Convolve["formulaexpression"] = formulaexpression
             PEAKSEARCHDICT_Convolve["Fit_with_Data_for_localMaxima"] = True
 
-        #             print 'Imin Imax dataimage_corrected', np.amin(dataimage_corrected), np.amax(dataimage_corrected)
-
         # --------------------------
         # launch peaksearch
         # -----------------------
@@ -1715,6 +1708,8 @@ def peaksearch_fileseries(fileindexrange,
 
         if Res in (False, None):
             print("No peak found for image file: ", filename_in)
+
+            nb_empty_files += 1
         #             Isorted, fitpeak, localpeak = None, None, None
         else:  # write file with comments
             Isorted, _, _ = Res[:3]
@@ -1739,8 +1734,19 @@ def peaksearch_fileseries(fileindexrange,
                                         overwrite=1,
                                         initialfilename=filename_in,
                                         comments=params_comments)
+            if writeResultDicts:                            
+                DictPeaksList[fileindex] = Isorted
+
+        progress = int(np.floor(file_ix/nbimages*nbstepsprogress))
+        if progress > progressstep:
+            print('Imageindex: %d, Task Progress : %.2f %%' % (fileindex, file_ix / nbimages * 100))
+            progressstep += 1
+        file_ix += 1
 
     print("\n\n\n*******************\n\n\n task of peaksearch COMPLETED!")
+    if computetime:
+        print('Execution time %.2f sec'%(ttt.time()-t0))
+    return DictPeaksList, file_ix, nb_empty_files
 
 
 def peaksearch_multiprocessing(fileindexrange, filenameprefix, suffix="", nbdigits=4,
@@ -1750,7 +1756,9 @@ def peaksearch_multiprocessing(fileindexrange, filenameprefix, suffix="", nbdigi
                                                     CCDLABEL="MARCCD165",
                                                     KF_DIRECTION="Z>0",
                                                     dictPeakSearch=None,
-                                                    nb_of_cpu=2):
+                                                    nb_of_cpu=2,
+                                                    verbose=0,
+                                                    writeResultDicts=0):
     r"""
     launch several processes in parallel
     """
@@ -1763,13 +1771,20 @@ def peaksearch_multiprocessing(fileindexrange, filenameprefix, suffix="", nbdigi
     except:
         raise ValueError("Need 2 file indices integers in fileindexrange=(indexstart, indexfinal)")
 
+    t00 = ttt.time()
+
+    max_nb_cpus = multiprocessing.cpu_count()
+    nb_cpus = min(nb_of_cpu, max_nb_cpus)
+
     fileindexdivision = GT.getlist_fileindexrange_multiprocessing(index_start, index_final, nb_of_cpu)
-    
-    jobs = []
-    for ii in list(range(nb_of_cpu)):
-        proc = multiprocessing.Process(target=peaksearch_fileseries,
-                                        args=(fileindexdivision[ii],
-                                            filenameprefix,
+
+    if nb_cpus > 1:
+        print('using %d cpu(s)'%nb_cpus)
+        fileindexdivision = GT.getlist_fileindexrange_multiprocessing(index_start, index_final, nb_cpus)
+        nbimages = index_final - index_start + 1
+        print('dispatch of fileindex ', fileindexdivision)
+        
+        peaksearch_fileseries.__defaults__ = (filenameprefix,
                                             suffix,
                                             nbdigits,
                                             dirname_in,
@@ -1777,9 +1792,34 @@ def peaksearch_multiprocessing(fileindexrange, filenameprefix, suffix="", nbdigi
                                             dirname_out,
                                             CCDLABEL,
                                             KF_DIRECTION,
-                                            dictPeakSearch))
-        jobs.append(proc)
-        proc.start()
+                                            dictPeakSearch,
+                                            verbose,
+                                            writeResultDicts,
+                                            0) # compute execution time / task
+
+        pool = multiprocessing.Pool(nb_of_cpu)
+        multiple_results = pool.map(peaksearch_fileseries, fileindexdivision)
+
+        # DictPeaksList, file_ix, nb_empty_files = multiple_results
+
+    t_mp = ttt.time() - t00
+    print("Execution time : %.2f" % t_mp)
+
+    if nb_cpus > 1:
+        nbtreatedimages = 0
+        nbzeropeaksimages = 0
+        for mres in multiple_results:
+            print('nb treated files, nb zero peaks file', mres[1], mres[2])
+            nbtreatedimages += mres[1]
+            nbzeropeaksimages += mres[2]
+        if nbzeropeaksimages != 0:
+            print('total nb of zero peaks file', nbzeropeaksimages)
+        else:
+            print('all %s images contain at least one peak'%nbtreatedimages)
+
+        # TODO  see end of indexFilesSeries()  to write a log file or hdf5 file with peaks props and other stas, nb of peaks per file, average nb , min and max number
+
+    return multiple_results, nbtreatedimages, nbzeropeaksimages
 
 
 def peaklist_dict(prefixfilename, startindex, finalindex, dirname=None):
